@@ -1,7 +1,7 @@
 from django.template import Context, Library
 from django.template.loader import get_template
 
-from model_nodes import ModelDetailNode, ModelListNode
+from model_nodes import ModelDetailNode, ModelTeaserNode, ModelListNode
 
 register = Library()
 
@@ -18,6 +18,19 @@ def as_detail_block(instance, title=None):
     return node.render(Context({'title':title}))
 
 
+@register.filter
+def as_teaser_block(instance, title=None):
+    """
+    Template filter that returns the given instance as a template-formatted
+    teaser.  Inserts two objects into the context:
+      ``instance`` - The model instance
+      ``fields`` - A list of (name, label, value) tuples representing the 
+                   instance's fields
+    """
+    node = ModelTeaserNode(instance)
+    return node.render(Context({'title':title}))
+
+
 @register.filter
 def as_list_block(queryset, list_title=None):
     """
